@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2.1
-id: yesod-1.4.2.1-9acb9e7a6ee115120170493743d7f9b0
-key: yesod_Evp98OKFqZ83RLCG5CnVTt
+id: yesod-1.4.2.1-d067b82caf44db5b577be82f8ef74e66
+key: yesod_63audFXaW4SIlOwvz0doUq
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,19 +21,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2.1
-hs-libraries: HSyesod-1.4.2.1-Evp98OKFqZ83RLCG5CnVTt
+hs-libraries: HSyesod-1.4.2.1-63audFXaW4SIlOwvz0doUq
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
     blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.12-6ce48f5ff8e654a7180ec1d44ce2af13
+    conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-4dbf6be6e769b875a57cb442a747af6f
+    monad-logger-0.3.18-77245c726e2e1fb18d9b7ba72ab04e41
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
@@ -48,10 +48,10 @@ depends:
     wai-logger-2.2.4.1-fb66803d5627851b4e6cf4f9505489de
     warp-3.2.4-afffa286f2a73716d3c875d3f70e8c61
     yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
-    yesod-auth-1.4.13-13eb60b8c85ce30ea4df6345e87fa407
-    yesod-core-1.4.20-239146128fca65f6c1bc44de3eec675c
-    yesod-form-1.4.7-f87c54f7a3a15348d1b5848f4d13423d
-    yesod-persistent-1.4.0.4-0995ca503f60c66644376333828a57d7
+    yesod-auth-1.4.13-afc8684a8e9e9b053e698b268da75a0d
+    yesod-core-1.4.20-a64b314810952b5a1be9638e42c84862
+    yesod-form-1.4.7-65d4c1c67a98e3c400d577cc5e8a906b
+    yesod-persistent-1.4.0.4-a374b45e8b618c21d99c5a049b52b954
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
